<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Admin;

use MicroEngine\Admin\Auth\Auth;
use MicroEngine\Admin\Views\AdminExtension;
use MicroEngine\Core\Support\ServiceProvider;
use MicroEngine\Admin\Managers\{
    UserManager, MeSystemManager
};
use MicroEngine\Admin\Services\{
    ConfigService, Log, Portlet
};
use MicroEngine\Admin\Controllers\{
    LicenseController, LogController, AuthController, SystemController, UserController, HomeController,
    ConfigController, BookmarkController
};

class AdminServiceProvider extends ServiceProvider
{
    /**
     * サービス登録
     */
    public function register()
    {
        $c = $this->c;

        $c['auth'] = function ($c) {
            return new Auth($c);
        };
        $c['meSystemManager'] = function ($c) {
            return new MeSystemManager($c);
        };
        $c['userManager'] = function ($c) {
            return new UserManager($c);
        };
        $c['portlet'] = function ($c) {
            return new Portlet($c);
        };
        $c['log'] = function ($c) {
            return new Log($c);
        };
        $c['configService'] = function ($c) {
            return new ConfigService($c);
        };
        $c['authController'] = function ($c) {
            return new AuthController($c);
        };
        $c['homeController'] = function ($c) {
            return new HomeController($c);
        };
        $c['userController'] = function ($c) {
            return new UserController($c);
        };
        $c['bookmarkController'] = function ($c) {
            return new BookmarkController($c);
        };
        $c['configController'] = function ($c) {
            return new ConfigController($c);
        };
        $c['licenseController'] = function ($c) {
            return new LicenseController($c);
        };
        $c['logController'] = function ($c) {
            return new LogController($c);
        };
        $c['systemController'] = function ($c) {
            return new SystemController($c);
        };
    }

    /**
     * サービス起動
     */
    public function boot()
    {
        // Twigエクステンションを登録
        $this->c->view->addExtension(new AdminExtension($this->c));

        // ルートを登録
        $route = new AdminRoute();
        $route->register($this->app);
    }
}
