<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Admin\Controllers;

use Psr\Http\Message\ResponseInterface;
use MicroEngine\Admin\Forms\BookmarkForm;
use Psr\Http\Message\ServerRequestInterface;
use MicroEngine\Core\Controllers\Controller;

class BookmarkController extends Controller
{
    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     */
    public function index(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        $user = $this->c->auth->getUser();
        $bookmarks = $user->getBookmarks();

        return $this->view->render(
            $response,
            'admin/views/bookmark/index.twig',
            compact('bookmarks')
        );
    }

    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     */
    public function edit(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        $form = new BookmarkForm();
        $user = $this->c->auth->getUser();

        $wrappedData = [];
        foreach ($user->getBookmarks() as $row) {
            $wrappedData[] = array_values($row);
        }

        // クエリパラメータがあればリストの最後にセットする
        $name = $request->getQueryParam('name');
        $url = $request->getQueryParam('url');
        if (!empty($url)) {
            $wrappedData[] = [$name, $url];
        }

        $json = json_encode($wrappedData);

        $form->setInputValue([
            'data' => $json,
        ]);

        return $this->view->render(
            $response,
            'admin/views/bookmark/edit.twig',
            compact('form')
        );
    }

    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     */
    public function update(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        $form = new BookmarkForm();
        $form->setInputValue($request->getParsedBody());

        // バリデーション
        if ($form->validate()) {
            $data = $form->getInputValues();
            $id = $this->c->auth->getUserId();

            // テーブルサービスを使ってデータを調整する
            $tableManager = $this->c->tableManager;
            $data = $tableManager->unwrapData($data, [
                'data_type' => 'matrix',
                'columns' => [
                    'name' => '名前',
                    'url' => 'URL',
                ]
            ]);
            $data = [
                'bookmarks' => $data['data']
            ];

            $this->c->userManager->update($id, $data);
            $this->flash->addMessage('success', 'ブックマークを更新しました。');

            return $response->withRedirect($this->c->router->pathFor('admin.bookmark.index'));
        } else {
            return $this->view->render(
                $response,
                'admin/views/bookmark/edit.twig',
                compact('form')
            );
        }
    }
}
