<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Admin\Controllers;

use Psr\Http\Message\ResponseInterface;
use MicroEngine\Core\Support\SystemInfo;
use Interop\Container\ContainerInterface;
use Psr\Http\Message\ServerRequestInterface;
use MicroEngine\Core\Controllers\Controller;

class SystemController extends Controller
{
    /**
     * @param ContainerInterface $c
     */
    public function __construct(ContainerInterface $c)
    {
        parent::__construct($c);

        $this->c->userManager->required('system');
    }

    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     */
    public function index(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        $systemInfo = new SystemInfo($this->c);
        $software = $systemInfo->software();
        $server = $systemInfo->server();
        $database = $systemInfo->database();
        $php = $systemInfo->php();
        $client = $systemInfo->client();

        return $this->view->render(
            $response,
            'admin/views/system/index.twig',
            compact('software', 'server', 'database', 'php', 'client')
        );
    }

    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     */
    public function phpinfo(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        $systemInfo = new SystemInfo($this->c);
        $phpinfo = $systemInfo->phpinfo();
        $response->getBody()->write($phpinfo);

        return $response;
    }

    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     * @throws \MicroEngine\Core\Exception\MeException
     */
    public function libs(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        $systemInfo = new SystemInfo($this->c);
        $libs = $systemInfo->libs();

        return $this->view->render(
            $response,
            'admin/views/system/libs.twig',
            compact('libs')
        );
    }
}
