<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Admin\Managers;

use MicroEngine\Admin\Models\MeSystem;
use Interop\Container\ContainerInterface;

class MeSystemManager
{
    /**
     * @var ContainerInterface
     */
    protected $c;

    /**
     * @param ContainerInterface $c
     */
    public function __construct(ContainerInterface $c)
    {
        $this->c = $c;
    }

    /**
     * 作成
     *
     * @param array $data
     * @return MeSystem
     */
    public function create(array $data): MeSystem
    {
        // 作成
        $meSystem = MeSystem::create($data);

        return $meSystem;
    }

    /**
     * 更新
     *
     * @param int $id
     * @param array $data
     * @return MeSystem
     */
    public function update(int $id, array $data): MeSystem
    {
        $meSystem = MeSystem::findOrFail($id);
        $meSystem->fill($data);
        $meSystem->save();

        return $meSystem;
    }

    /**
     * 名前を指定して更新
     *
     * @param string $name
     * @param $value
     * @return MeSystem
     */
    public function updateByName(string $name, $value): MeSystem
    {
        $meSystem = MeSystem::where('name', $name)->first();
        $meSystem->value = $value;
        $meSystem->save();

        return $meSystem;
    }

    /**
     * 削除
     *
     * @param int $id
     * @return MeSystem
     */
    public function destroy(int $id): MeSystem
    {
        $meSystem = MeSystem::findOrFail($id);
        $meSystem->delete();

        return $meSystem;
    }
}
