<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Admin\Services;

use Interop\Container\ContainerInterface;

class Portlet
{
    /**
     * @var ContainerInterface
     */
    protected $c;

    /**
     * @param ContainerInterface $c
     */
    public function __construct(ContainerInterface $c)
    {
        $this->c = $c;
    }

    /**
     * ポートレットの内容を表示
     *
     * @param string $portlet
     * @return string
     */
    public function portlet(string $portlet): string
    {
        $portletsConfig = config('admin.portlets');
        if (!isset($portletsConfig[$portlet])) {
            return '';
        }
        $config = $portletsConfig[$portlet];
        $package = $config['package'] ?? 'App';

        // class名取得
        if (isset($config['class'])) {
            // class が設定されている場合
            $class = $config['class'];
        } elseif ($package === 'App') {
            // ユーザー定義ポートレットが用意されている場合
            $class = 'App\\Portlets\\' . ucfirst($portlet);
        } else {
            // パッケージ名が指定されている場合
            $class = 'MicroEngine\\' . $package . '\\Portlets\\' . ucfirst($portlet);
        }

        // テンプレートパス取得
        $template = 'views/portlet/' . $portlet . '.twig';
        if ($package === 'App') {
            $template = '@app/' . $template;
        } else {
            $template = strtolower($package) . '/' . $template;
        }

        $data = [];
        if ($class) {
            $obj = new $class($this->c);
            $data = $obj();
        }

        /* @var Twig $view */
        $view = $this->c->view;

        return $view->getEnvironment()->render(
            $template,
            $data
        );
    }
}
