<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Cms\Controllers;

use Psr\Http\Message\ResponseInterface;
use Interop\Container\ContainerInterface;
use MicroEngine\Core\Controllers\Controller;
use Psr\Http\Message\ServerRequestInterface;

class CacheController extends Controller
{
    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     */
    public function index(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        $htmlCache = $this->c->htmlCache;
        // 有効期限取得
        $expirationDate = $htmlCache->expirationDate();
        // キャッシュ作成日時取得
        $createdAt = $htmlCache->createdAt();

        return $this->view->render(
            $response,
            'cms/views/cache/index.twig',
            compact('expirationDate', 'createdAt')
        );
    }

    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  array $args
     * @return ResponseInterface
     */
    public function clear(ServerRequestInterface $request, ResponseInterface $response, array $args): ResponseInterface
    {
        // HTMLキャッシュ削除を実行する
        $this->c->htmlCache->clear();
        $this->flash->addMessage('success', 'HTMLキャッシュを削除しました。');

        return $response->withRedirect($this->c->router->pathFor('admin.cache.index'));
    }
}
