<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Core\Handler;

use Slim\Handlers\Error as SlimError;
use MicroEngine\Core\Exception\MeException;

class Error extends SlimError
{
    use HandlerTrait;

    /**
     * エラーメッセージのHTMLをレンダリングする
     *
     * @param \Exception $exception
     * @return string
     */
    protected function renderHtmlErrorMessage(\Exception $exception)
    {
        $title = 'アプリケーションエラー';

        if ($this->displayErrorDetails) {
            // 詳細エラー表示が有効な場合
            $html = '<p>このアプリケーションは次のエラーが発生したため実行することができません：</p><main>'
                . '<article><h2>詳細</h2>'
                . $this->renderHtmlException($exception) . '</article>';

            while ($exception = $exception->getPrevious()) {
                $html .= '<article><h2>以前の例外</h2>'
                    . $this->renderHtmlExceptionOrError($exception) . '</article>';
            }
            $html .= '</main>';
        } else if (is_login()) {
            // 詳細エラー表示は無効だが、ログイン中の場合はエラーメッセージだけ表示する
            $html = '<p>このアプリケーションは次のエラーが発生したため実行することができません：</p><main>'
                . '<article><h2>詳細</h2>'
                . '<p>' . $exception->getMessage() . '</p>'
                . '</article></main>';
        } else {
            // 詳細エラー表示が無効で、ログインしていない場合は内容は一切表示しない
            $html = '<p>Webサイトでエラーが発生しました。ご不便をおかけして申し訳ありません。</p>';
        }

        return $this->renderTemplate($title, $html);
    }

    /**
     * displayErrorDetailsがfalseの場合はエラーログを記録する。それに加えてCMSのログファイルに記録する。
     *
     * @param \Exception|\Throwable $throwable
     * @return void
     */
    protected function writeToErrorLog($throwable)
    {
        parent::writeToErrorLog($throwable);

        global $app;
        $logger = $app->getContainer()->get('logger');

        $class = get_class($throwable);
        if ($class === MeException::class) {
            // MeExceptionはエラーレベルで記録する
            $logger->addError($throwable->getMessage());
        } else {
            // MeException以外の例外はワーニングレベルで記録する
            $logger->addWarning($throwable->getMessage());
        }
    }
}
