<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Core\Handler;

use Slim\Handlers\PhpError as SlimPhpError;

class PhpError extends SlimPhpError
{
    use HandlerTrait;

    /**
     * エラーページのHTMLをレンダリングする
     *
     * @param \Throwable $error
     * @return string
     */
    protected function renderHtmlErrorMessage(\Throwable $error)
    {
        $title = 'アプリケーションエラー';

        if ($this->displayErrorDetails) {
            // 詳細エラー表示が有効な場合
            $html = '<p>このアプリケーションは次のエラーが発生したため実行することができません：</p><main>'
                . '<article><h2>詳細</h2>'
                . $this->renderHtmlError($error) . '</article>';

            while ($exception = $error->getPrevious()) {
                $html .= '<article><h2>以前の例外</h2>'
                    . $this->renderHtmlExceptionOrError($error) . '</article>';
            }
            $html .= '</main>';
        } else {
            // 詳細エラー表示が無効で、ログインしていない場合は内容は一切表示しない
            $html = '<p>Webサイトでエラーが発生しました。ご不便をおかけして申し訳ありません。</p>';
        }

        return $this->renderTemplate($title, $html);
    }
}
