<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Core\Mail;

use Swift_Mailer;
use Swift_Message;
use Slim\Views\Twig;
use MicroEngine\Core\Interfaces\DataInterface;

class MailComposer
{
    /**
     * @var Twig
     */
    protected $view;
    /**
     * @var Swift_Mailer
     */
    protected $mailer;

    /**
     * MailComposer constructor.
     * @param Twig $view
     * @param Swift_Mailer $mailer
     */
    public function __construct(Twig $view, Swift_Mailer $mailer)
    {
        $this->view = $view;
        $this->mailer = $mailer;
    }

    /**
     * メール送信
     *
     * @param string $formKey
     * @param array $config
     * @param DataInterface $data
     */
    public function send(string $formKey, array $config, DataInterface $data)
    {
        if (isset($config['mail'])) {
            $this->sendMail($formKey, $config['mail'], $data, 'body.twig');
        }
        if (isset($config['reply_mail'])) {
            $this->sendMail($formKey, $config['reply_mail'], $data, 'reply_body.twig');
        }
    }

    /**
     * メール送信処理
     *
     * @param string $formKey
     * @param array $mailConfig
     * @param DataInterface $data
     * @param string $bodyTemplate
     * @return int
     */
    protected function sendMail(string $formKey, array $mailConfig, DataInterface $data, string $bodyTemplate = 'body.twig'): int
    {
        $body = $this->view->fetch('/emails/' . $formKey . '/' . $bodyTemplate, ['data' => $data]);

        $message = (new Swift_Message($mailConfig['subject']))
            ->setFrom($mailConfig['from'])
            ->setBody($body);

        if (isset($mailConfig['to_field'])) {
            $message->setTo($data->get($mailConfig['to_field']));
        } else {
            $message->setTo($mailConfig['to']);
        }
        if (!empty($mailConfig['cc'])) {
            $message->setCc($mailConfig['cc']);
        }
        if (!empty($mailConfig['bcc'])) {
            $message->setBcc($mailConfig['mail']['bcc']);
        }
        if (!empty($mailConfig['reply_to_field'])) {
            $message->setReplyTo($data->get($mailConfig['reply_to_field']));
        } elseif (!empty($mailConfig['reply_to'])) {
            $message->setReplyTo($mailConfig['reply_to']);
        }
        return $this->mailer->send($message);
    }
}
