<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Core\Validation;

use Rakit\Validation\Rule;
use Illuminate\Database\Capsule\Manager as DB;

/**
 * 複合ユニークルール
 * 複数のカラムでユニークになることを確認する
 * Class CompositeUniqueRule
 * @package MicroEngine\Core\Validation
 */
class UniqueCompositeRule extends Rule
{
    /**
     * @var string
     */
    protected $message = ":attribute :value はすでに使用されています。";
    /**
     * @var array
     */
    protected $fillableParams = ['table', 'column', 'filter_column', 'except_column'];

    /**
     * @param $value
     * @return bool
     */
    public function check($value): bool
    {
        // 必須パラメータが存在することを確認
        $this->requireParameters(['table', 'column', 'filter_column']);

        // パラメータを取得
        // DBテーブル名
        $table = $this->parameter('table');
        // 値と照合するカラム名
        $column = $this->parameter('column');
        // 絞り込むカラム名
        $filterColumn = $this->parameter('filter_column');
        // 絞り込むカラムの値
        $exceptColumn = $this->parameter('except_column');

        // 他のフィールド値を取得
        $filterValue = $this->validation->getValue($filterColumn);
        $exceptValue = $this->validation->getValue($exceptColumn);

        // クエリを作成して実行する
        $query = DB::table($table)->where($filterColumn, $filterValue)->where($column, $value);
        if ($exceptValue) {
            $query->where($exceptColumn, '!=', $exceptValue);
        }
        $count = $query->count();

        // クエリのcount結果が0ならtrue、0以外はfalseを返す
        return intval($count) === 0;
    }
}
