<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Core\Views;

use Interop\Container\ContainerInterface;

class MenuManager
{
    /**
     * @var ContainerInterface
     */
    protected $c;
    /**
     * @var string 現在のメインメニューカテゴリー
     */
    protected $main;
    /**
     * @var string 現在のサブメニュー
     */
    protected $sub;
    /**
     * @var array メニュー情報
     */
    protected $menus = [];

    /**
     * @param ContainerInterface $c
     */
    public function __construct(ContainerInterface $c)
    {
        $this->c = $c;
        $this->menus = config('settings.navigation');
    }

    /**
     * メニュー登録
     *
     * @param string $menuKey
     * @param array $menus
     */
    public function addMenus(string $menuKey, array $menus)
    {
        $this->menus[$menuKey] = $menus;
    }

    /**
     * メニュー取得
     *
     * @return array
     */
    public function mainMenu(): array
    {
        $ret = $this->menus;

        // display_order でソートする。
        $displayOrders = [];
        $menuKeys = [];
        foreach ($ret as $menuKey => &$menu) {
            if (!isset($menu['display_order'])) {
                unset($ret[$menuKey]);
                // display_order 未定義の場合はメインメニューには表示しない
                continue;
            }
            $displayOrders[] = $menu['display_order'];
            $menuKeys[] = $menuKey;
            if ($menuKey === $this->main) {
                $menu['active'] = true;
            } else {
                $menu['active'] = false;
            }
        }
        array_multisort($displayOrders, $menuKeys, $ret);

        return $ret;
    }

    /**
     * サブメニュー取得
     *
     * @return array
     */
    public function subMenu(): array
    {
        $ret = [];
        $main = $this->main;
        $menus = $this->roleMenus();

        if (strlen($main) && isset($menus[$main])) {
            $ret = $menus[$main]['menus'];
        } elseif (count($menus) > 0) {
            $menuKeys = array_keys($menus);
            $firstKey = array_shift($menuKeys);

            $ret = $menus[$firstKey]['menus'];
        }
        foreach ($ret as $key => &$menu) {
            if ($key === $this->sub) {
                $menu['active'] = true;
            } else {
                $menu['active'] = false;
            }
        }

        return $ret;
    }

    /**
     * 現在メニューをセット
     *
     * @param string $main
     * @param string|null $sub
     */
    public function setCurrent(string $main, string $sub = null)
    {
        $this->main = $main;
        $this->sub = $sub;
    }

    /**
     * ロール用のメニューを取得
     *
     * @return array
     */
    protected function roleMenus()
    {
        $menus = $this->menus;

        // ログインユーザーのロール設定を取得
        $config = $this->c->userManager->loginUserRoleConfig();

        foreach ($config['hidden_menus'] as $main => $subMenus) {
            foreach ($subMenus as $menu) {
                if (isset($menus[$main]['menus'][$menu])) {
                    unset($menus[$main]['menus'][$menu]);
                }
            }
        }
        return $menus;
    }
}
