
SET foreign_key_checks = 0;

DROP TABLE if EXISTS me_systems;
CREATE TABLE me_systems (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  name          VARCHAR(64) NOT NULL UNIQUE,
  value         TEXT NOT NULL,
  created_at    DATETIME,
  updated_at    DATETIME
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

INSERT INTO me_systems (name, value, created_at, updated_at) VALUES
  ('schema_version', '1', now(), now()),
  ('install_date', now(), now(), now());

DROP TABLE if EXISTS users;
CREATE TABLE users (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  login_id      VARCHAR(32) NOT NULL UNIQUE,
  password      VARCHAR(256) NOT NULL,
  role          VARCHAR(32) NOT NULL,
  name          VARCHAR(128) NOT NULL,
  email         VARCHAR(256) NOT NULL DEFAULT '',
  portlets      TEXT,
  bookmarks     TEXT,
  note          TEXT,
  failure_count SMALLINT UNSIGNED NOT NULL DEFAULT 0,
  failed_at     DATETIME,
  created_at    DATETIME,
  updated_at    DATETIME
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS categories;
CREATE TABLE categories (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  parent_id     INT UNSIGNED NOT NULL DEFAULT 0,
  name          VARCHAR(128) NOT NULL DEFAULT '',
  dir           VARCHAR(191) NOT NULL UNIQUE,
  has_index     BOOLEAN NOT NULL DEFAULT 0,
  display_order SMALLINT NOT NULL DEFAULT 10,
  create_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

INSERT INTO categories (
  parent_id, name, dir, display_order, created_at, updated_at
) VALUES (
  0, 'ホーム', '/', 10, now(), now()
);

DROP TABLE IF EXISTS pages;
CREATE TABLE pages (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  draft_id      INT UNSIGNED,
  type          VARCHAR(64) NOT NULL,
  template      VARCHAR(64) NOT NULL DEFAULT '',
  category_id   INT UNSIGNED NOT NULL DEFAULT 0,
  filename      VARCHAR(64) NOT NULL,
  path          VARCHAR(256) NOT NULL,
  name          VARCHAR(128) NOT NULL,
  fields        TEXT,
  display_order SMALLINT NOT NULL DEFAULT 10,
  sitemap       TINYINT NOT NULL DEFAULT 1,
  date          DATETIME,
  visibility    TINYINT NOT NULL DEFAULT 1,
  published_at  DATETIME,
  closed_at     DATETIME,
  create_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  UNIQUE(category_id, filename),
  INDEX(path(191)),
  INDEX(create_user_id),
  INDEX(update_user_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS page_revisions;
CREATE TABLE page_revisions (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  page_id       INT UNSIGNED NOT NULL,
  revision_type VARCHAR(16) NOT NULL DEFAULT 'trunk',
  type          VARCHAR(64) NOT NULL,
  template      VARCHAR(64) NOT NULL DEFAULT '',
  category_id   INT UNSIGNED NOT NULL DEFAULT 0,
  filename      VARCHAR(64) NOT NULL,
  path          VARCHAR(256) NOT NULL,
  name          VARCHAR(128) NOT NULL,
  fields        TEXT,
  display_order SMALLINT NOT NULL DEFAULT 10,
  sitemap       TINYINT NOT NULL DEFAULT 1,
  date          DATETIME,
  visibility    TINYINT NOT NULL DEFAULT 1,
  published_at  DATETIME,
  closed_at     DATETIME,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(page_id),
  INDEX(update_user_id),
  CONSTRAINT fk_page_revisions_page_id FOREIGN KEY (page_id) REFERENCES pages(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS page_metas;
CREATE TABLE page_metas (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  page_id       INT UNSIGNED NOT NULL,
  name          VARCHAR(128) NOT NULL,
  value         TEXT,
  INDEX(page_id),
  CONSTRAINT fk_page_metas_page_id FOREIGN KEY (page_id) REFERENCES pages(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS page_searches;
CREATE TABLE page_searches (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  page_id       INT UNSIGNED NOT NULL,
  content       TEXT,
  INDEX(page_id),
  CONSTRAINT fk_page_searches_page_id FOREIGN KEY (page_id) REFERENCES pages(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS collections;
CREATE TABLE collections (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  draft_id      INT UNSIGNED,
  type          VARCHAR(64) NOT NULL,
  name          VARCHAR(128) NOT NULL,
  fields        TEXT,
  display_order SMALLINT NOT NULL DEFAULT 10,
  date          DATETIME,
  visibility    TINYINT NOT NULL DEFAULT 1,
  published_at  DATETIME,
  closed_at     DATETIME,
  create_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(create_user_id),
  INDEX(update_user_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS collection_revisions;
CREATE TABLE collection_revisions (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  collection_id INT UNSIGNED NOT NULL,
  revision_type VARCHAR(16) NOT NULL DEFAULT 'trunk',
  type          VARCHAR(64) NOT NULL,
  name          VARCHAR(128) NOT NULL,
  fields        TEXT,
  display_order SMALLINT NOT NULL DEFAULT 10,
  date          DATETIME,
  visibility    TINYINT NOT NULL DEFAULT 1,
  published_at  DATETIME,
  closed_at     DATETIME,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(collection_id),
  INDEX(update_user_id),
  CONSTRAINT fk_collection_revisions_collection_id FOREIGN KEY (collection_id) REFERENCES collections(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS collection_metas;
CREATE TABLE collection_metas
(
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  collection_id INT UNSIGNED NOT NULL,
  name          VARCHAR(128) NOT NULL,
  value         TEXT,
  INDEX(collection_id),
  CONSTRAINT fk_collection_metas_collection_id FOREIGN KEY (collection_id) REFERENCES collections(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS collection_searches;
CREATE TABLE collection_searches (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  collection_id INT UNSIGNED NOT NULL,
  content       TEXT,
  INDEX(collection_id),
  CONSTRAINT fk_collection_searches_collection_id FOREIGN KEY (collection_id) REFERENCES collections(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS modules;
CREATE TABLE modules (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  type          VARCHAR(64) NOT NULL UNIQUE,
  fields        TEXT,
  create_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(create_user_id),
  INDEX(update_user_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS module_revisions;
CREATE TABLE module_revisions (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  module_id     INT UNSIGNED NOT NULL,
  revision_type VARCHAR(16) NOT NULL DEFAULT 'trunk',
  type          VARCHAR(64) NOT NULL,
  fields        TEXT,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(module_id),
  INDEX(update_user_id),
  CONSTRAINT fk_module_revisions_module_id FOREIGN KEY (module_id) REFERENCES modules(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS calendars;
CREATE TABLE calendars (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  type          VARCHAR(64) NOT NULL,
  date          DATE NOT NULL,
  fields        TEXT,
  visibility    TINYINT NOT NULL DEFAULT 1,
  published_at  DATETIME,
  closed_at     DATETIME,
  create_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  UNIQUE (type, date),
  INDEX(create_user_id),
  INDEX(update_user_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS calendar_revisions;
CREATE TABLE calendar_revisions (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  calendar_id   INT UNSIGNED NOT NULL,
  revision_type VARCHAR(16) NOT NULL DEFAULT 'trunk',
  type          VARCHAR(64) NOT NULL,
  date          DATE NOT NULL,
  fields        TEXT,
  visibility    TINYINT NOT NULL DEFAULT 1,
  published_at  DATETIME,
  closed_at     DATETIME,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(calendar_id),
  INDEX(update_user_id),
  CONSTRAINT fk_calendar_revisions_calendar_id FOREIGN KEY (calendar_id) REFERENCES calendars(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS tables;
CREATE TABLE tables (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  type          VARCHAR(64) NOT NULL UNIQUE,
  data_type     VARCHAR(16) NOT NULL,
  data          TEXT,
  line_count    INT UNSIGNED NOT NULL,
  create_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(create_user_id),
  INDEX(update_user_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS table_revisions;
CREATE TABLE table_revisions (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  table_id      INT UNSIGNED NOT NULL,
  revision_type VARCHAR(16) NOT NULL DEFAULT 'trunk',
  type          VARCHAR(64) NOT NULL,
  data_type     VARCHAR(16) NOT NULL,
  data          TEXT,
  line_count    INT UNSIGNED NOT NULL,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(table_id),
  INDEX(update_user_id),
  CONSTRAINT fk_table_revisions_table_id FOREIGN KEY (table_id) REFERENCES tables(id) ON DELETE CASCADE
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

INSERT INTO tables (type, data_type, data, created_at, updated_at, line_count) VALUES
  ('site', 'hash','{"name":"\\u30b5\\u30f3\\u30d7\\u30eb\\u682a\\u5f0f\\u4f1a\\u793e","copyright":"\\u00a9 2018 MicroEngine Inc."}',
   now(), now(), 2);

DROP TABLE IF EXISTS files;
CREATE TABLE files (
  id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  is_dir        BOOLEAN NOT NULL DEFAULT 0,
  dir           VARCHAR(191) NOT NULL,
  filename      VARCHAR(64) NOT NULL,
  extension     VARCHAR(16)  NOT NULL DEFAULT '',
  size          INT UNSIGNED NOT NULL DEFAULT 0,
  name          VARCHAR(128),
  create_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  update_user_id INT UNSIGNED NOT NULL DEFAULT 0,
  created_at    DATETIME,
  updated_at    DATETIME,
  INDEX(create_user_id),
  INDEX(update_user_id),
  UNIQUE(dir, filename)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

SET foreign_key_checks = 1;
