<?php
/**
 * MicroEngine CMS
 * https://microengine.jp
 *
 * (c) 2018 MicroEngine Inc.
 */

namespace MicroEngine\Site\Middleware;

use Psr\Http\Message\ResponseInterface;
use MicroEngine\Core\Middleware\Middleware;
use Psr\Http\Message\ServerRequestInterface;

class HtmlCacheMiddleware extends Middleware
{
    /**
     * @param  ServerRequestInterface $request
     * @param  ResponseInterface $response
     * @param  callable $next
     * @return ResponseInterface
     */
    public function __invoke(ServerRequestInterface $request, ResponseInterface $response, callable $next): ResponseInterface
    {
        $response = $next($request, $response);

        // httpメソッドを確認
        if (!$request->isGet()) {
            // getメソッド以外はスルー
            return $response;
        }

        if ($this->c->auth->authenticated()) {
            // ログイン中はキャッシュを作成しない。
            return $response;
        }

        $htmlCache = $this->c->htmlCache;
        if (!$htmlCache->isEnabled()) {
            // キャッシュ機能が無効の場合はスルー
            return $response;
        }

        // 有効期限確認
        $htmlCache->checkExpired();

        $path = $request->getUri()->getPath();
        if (!$htmlCache->has($path)) {
            // キャッシュファイルが無ければファイルを保存する。
            $body = $response->getBody();
            $body->rewind();
            $content = $body->getContents();
            $htmlCache->put($path, $content);
        }
        return $response;
    }
}
